
/* Drop Indexes */

DROP INDEX BusinessTypeMaster_Index1;
DROP INDEX ComponentLinkMaster_Index1;
DROP INDEX ComponentLinkMaster_Index2;
DROP INDEX ComponentMaster_Index1;
DROP INDEX ComponentToTypeMaster_Index1;
DROP INDEX ComponentToTypeMaster_Index2;
DROP INDEX ConstructionSpecMaster_Index1;
DROP INDEX DepartmentMaster_index1;
DROP INDEX HolidayCalender_Index1;
DROP INDEX HolidayCalenderMaster_Index2;
DROP INDEX HolidayCalenderMaster_Index3;
DROP INDEX PersonInChargeMaster_Index1;
DROP INDEX PersonInChargeMaster_Index2;
DROP INDEX SubContractorJobItem_Index1;
DROP INDEX SubContractorJobItem_Index2;
DROP INDEX SubContractorJobLink_Index1;
DROP INDEX SubContractorJobLink_Index2;
DROP INDEX SubContractorMaster_Index1;
DROP INDEX TermMaster_Index1;
DROP INDEX UnitMaster_Index1;



/* Drop Tables */

DROP TABLE ApprovalMaster CASCADE CONSTRAINTS;
DROP TABLE BusinessTypeMaster CASCADE CONSTRAINTS;
DROP TABLE CommonCostLarge CASCADE CONSTRAINTS;
DROP TABLE CommonCostLinkMS CASCADE CONSTRAINTS;
DROP TABLE CommonCostMiddle CASCADE CONSTRAINTS;
DROP TABLE CommonCostMiddleSearchWord CASCADE CONSTRAINTS;
DROP TABLE ComponentLinkMaster CASCADE CONSTRAINTS;
DROP TABLE ComponentMaster CASCADE CONSTRAINTS;
DROP TABLE ComponentToTypeMaster CASCADE CONSTRAINTS;
DROP TABLE ConstructionItemMaster CASCADE CONSTRAINTS;
DROP TABLE ConstructionSpecMaster CASCADE CONSTRAINTS;
DROP TABLE ConstructionSpecUnitPrice CASCADE CONSTRAINTS;
DROP TABLE ConstructionTypeMaster CASCADE CONSTRAINTS;
DROP TABLE DepartmentExpensesMaster CASCADE CONSTRAINTS;
DROP TABLE DepartmentMaster CASCADE CONSTRAINTS;
DROP TABLE DivisionMaster CASCADE CONSTRAINTS;
DROP TABLE ExpensesMaster CASCADE CONSTRAINTS;
DROP TABLE HolidayCalenderMaster CASCADE CONSTRAINTS;
DROP TABLE OrderersMaster CASCADE CONSTRAINTS;
DROP TABLE PersonInChargeMaster CASCADE CONSTRAINTS;
DROP TABLE SubContractorItemMaster CASCADE CONSTRAINTS;
DROP TABLE SubContractorJobCategory CASCADE CONSTRAINTS;
DROP TABLE SubContractorJobItem CASCADE CONSTRAINTS;
DROP TABLE SubContractorJobLink CASCADE CONSTRAINTS;
DROP TABLE SubContractorMaster CASCADE CONSTRAINTS;
DROP TABLE SuppliersMaster CASCADE CONSTRAINTS;
DROP TABLE SystemMaster CASCADE CONSTRAINTS;
DROP TABLE TermMaster CASCADE CONSTRAINTS;
DROP TABLE UnitMaster CASCADE CONSTRAINTS;
DROP TABLE VehicleMaster CASCADE CONSTRAINTS;
DROP TABLE VehicleRecordData CASCADE CONSTRAINTS;




/* Create Tables */

-- 承認経路マスタ
CREATE TABLE ApprovalMaster
(
	-- 承認機能番号
	ApprovalCode number(3,0) NOT NULL,
	-- 部署コード
	DepartmentCode number(5,0) NOT NULL,
	-- 枝番
	SeqNo number(2,0) NOT NULL,
	-- 表示順
	DisplayOrder number(2,0) NOT NULL,
	-- 承認者コード
	ApprovalPerson number(8,0) NOT NULL,
	-- 承認権限区分
	ApprovalAuthority number(1) NOT NULL,
	-- 登録年月日
	EntryDate date,
	-- 更新年月日
	UpdateDate date,
	PRIMARY KEY (ApprovalCode, DepartmentCode, SeqNo)
);


-- 法人格マスタ
CREATE TABLE BusinessTypeMaster
(
	-- 業種コード
	BusinessTypeCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 業種名
	BusinessTypeName nvarchar2(100) DEFAULT '' NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (BusinessTypeCode)
);


-- 共通費大項目マスタ
CREATE TABLE CommonCostLarge
(
	-- 大項目キー
	LargeCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 大項目名称
	LargeName nvarchar2(50) DEFAULT '' NOT NULL,
	-- 説明書き
	CommentText nvarchar2(120),
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (LargeCode)
);


-- 共通費工種関連マスタ
CREATE TABLE CommonCostLinkMS
(
	-- 大項目キー
	LargeCode number(5,0) NOT NULL,
	-- 中項目キー
	MiddleCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 登録年月日
	EntryDate date,
	-- 更新年月日
	UpdateDate date,
	PRIMARY KEY (LargeCode, MiddleCode, ItemCode)
);


-- 共通費中項目マスタ
CREATE TABLE CommonCostMiddle
(
	-- 大項目キー
	LargeCode number(5,0) NOT NULL,
	-- 中項目キー
	MiddleCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 中項目名称
	MiddleName nvarchar2(50) DEFAULT '' NOT NULL,
	-- 説明書き
	CommentText nvarchar2(120),
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (LargeCode, MiddleCode)
);


-- 共通費中項目キーマスタ
CREATE TABLE CommonCostMiddleSearchWord
(
	-- 大項目キー
	LargeCode number(5,0) NOT NULL,
	-- 中項目キー
	MiddleCode number(5,0) NOT NULL,
	-- 順序
	SeqNo number(5,0) NOT NULL,
	-- 検索項目
	SearchWord nvarchar2(50) DEFAULT '' NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (LargeCode, MiddleCode, SeqNo)
);


-- 構成工種関連マスタ
CREATE TABLE ComponentLinkMaster
(
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ComponentCode, ItemCode)
);


-- 構成マスタ
CREATE TABLE ComponentMaster
(
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 構成名称
	ComponentName nvarchar2(120) DEFAULT '' NOT NULL,
	-- 下位項目フラグ
	SubItemsFlg number(1),
	-- 直接入力フラグ
	DirectInputFlg number(1),
	-- 自社経費フラグ
	MyExpensesFlg number(1),
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ComponentCode)
);


-- 構成工事種別関連マスタ
CREATE TABLE ComponentToTypeMaster
(
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工事種別コード
	TypeCode number(5,0) NOT NULL,
	-- ダミー項目
	Dummy number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ComponentCode, TypeCode)
);


-- 工種マスタ
CREATE TABLE ConstructionItemMaster
(
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 工種名称
	ItemName nvarchar2(120) DEFAULT '' NOT NULL,
	-- 下位項目フラグ
	SubItemsFlg number(1),
	-- 自社経費フラグ
	MyExpensesFlg number(1) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ItemCode)
);


-- 作業マスタ
CREATE TABLE ConstructionSpecMaster
(
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 作業キー
	SpecCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 作業名称
	ItemName nvarchar2(120) DEFAULT '',
	-- 作業名称
	SpecName nvarchar2(120),
	-- 単位名称
	UnitName nvarchar2(30),
	-- 単価
	UnitPrice number(9,2) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ItemCode, SpecCode)
);


-- 作業単価マスタ
CREATE TABLE ConstructionSpecUnitPrice
(
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 作業キー
	SpecCode number(5,0) NOT NULL,
	-- 工事種別コード
	ConstructionTypeCode number(5,0) NOT NULL,
	-- 単価
	UnitPrice number(9,2) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ComponentCode, ItemCode, SpecCode, ConstructionTypeCode)
);


-- 工事種別マスタ
CREATE TABLE ConstructionTypeMaster
(
	-- 種別コード
	TypeCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 名称
	NameString nvarchar2(100) DEFAULT '' NOT NULL,
	-- 工事種別フラグ
	PublicFlg number(1) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (TypeCode)
);


-- 部署経費率マスタ
CREATE TABLE DepartmentExpensesMaster
(
	-- 部署コード
	DepartmentCode number(5,0) NOT NULL,
	-- 事業期
	ExpensesPeriod number(4,0) NOT NULL,
	-- 経費名称コード
	NameCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 経費率
	ExpensesRatio number(4,2) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (DepartmentCode, ExpensesPeriod, NameCode)
);


-- 部署マスタ
CREATE TABLE DepartmentMaster
(
	-- 部署コード
	DepartmentCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 部署名
	DepartmentString nvarchar2(100) DEFAULT '' NOT NULL,
	-- 行動予定表示フラグ
	ActionScheduleFlg number(1) NOT NULL,
	-- 人員配置表示フラグ
	StaffAssignFlg number(1) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (DepartmentCode)
);


-- 区分マスタ
CREATE TABLE DivisionMaster
(
	-- 区分コード
	DivisionCode number(5,0) NOT NULL,
	-- 名称コード
	NameCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 名称
	NameString nvarchar2(100) DEFAULT '' NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (DivisionCode, NameCode)
);


-- 経費率マスタ
CREATE TABLE ExpensesMaster
(
	-- 工事種別コード
	DivisionCode number(5,0) NOT NULL,
	-- 経費名称コード
	NameCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 経費率
	ExpensesRatio number(4,2) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (DivisionCode, NameCode)
);


-- 会社休日マスタ
CREATE TABLE HolidayCalenderMaster
(
	-- 休日
	Holiday date NOT NULL,
	-- 営業年度
	BusinessYear number(4,0) NOT NULL,
	-- 該当月
	TargetMonth number(2,0) NOT NULL,
	-- 該当日
	TargetDay number(2,0) NOT NULL,
	PRIMARY KEY (Holiday)
);


-- 発注者マスタ
CREATE TABLE OrderersMaster
(
	-- 発注者区分
	OrderCotegory number(5,0) NOT NULL,
	-- 発注者コード
	OrderersCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 法人格名称
	CorporateStatusName nvarchar2(100),
	-- 法人格名称位置
	CorporateStatusPoint number(1),
	-- 発注者名1
	OrderersName1 nvarchar2(60) DEFAULT '' NOT NULL,
	-- 発注者名２
	OrderersName2 nvarchar2(60),
	-- 郵便番号
	ZipCode varchar2(8),
	-- 住所１
	Address1 nvarchar2(60),
	-- 住所2
	Address2 nvarchar2(60) DEFAULT '',
	-- 住所3
	Address3 nvarchar2(60),
	-- 電話番号
	PhoneNumber varchar2(13) DEFAULT '',
	-- FAX番号
	FaxNumber varchar2(13) DEFAULT '',
	-- 備考
	Note nvarchar2(300) DEFAULT '',
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (OrderCotegory, OrderersCode)
);


-- 担当者マスタ
CREATE TABLE PersonInChargeMaster
(
	-- 担当者コード
	PersonCode number(8,0) NOT NULL,
	-- 表示順
	DisplayOrder number(8,0) NOT NULL,
	-- 担当者名
	PersonName nvarchar2(60) DEFAULT '' NOT NULL,
	-- 使用開始年月日
	StartDate date NOT NULL,
	-- 使用終了年月日
	EndDate date,
	-- パスワード
	PassWord varchar2(16),
	-- 機密区分
	SecurityManagement number(1) NOT NULL,
	-- メッセージ背景色
	MsgBackColor varchar2(8),
	-- 表示・印刷名称
	DisplayString nvarchar2(20),
	-- 部署コード
	DepartmentCode number(5,0),
	-- 月給金額
	MonthlySalary number(11,3) NOT NULL,
	-- 年俸金額
	YearSalary number(12,3) NOT NULL,
	-- 資格入力欄
	Qualification nvarchar2(120),
	-- 印鑑表示名
	SealPrintName nvarchar2(5),
	-- 社員区分
	EmployeeClassFlg number(1) NOT NULL,
	-- 台帳計算対象フラグ
	LedgerFlg number(1) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode)
);


-- 協力会社工種マスタ
CREATE TABLE SubContractorItemMaster
(
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 工種名称
	ItemName nvarchar2(120) DEFAULT '' NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ItemCode)
);


-- 協力会社職種マスタ
CREATE TABLE SubContractorJobCategory
(
	-- 職種キー
	JobCategoryCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 職種名称
	JobCategoryName nvarchar2(120) DEFAULT '' NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (JobCategoryCode)
);


-- 協力会社施工工種データ
CREATE TABLE SubContractorJobItem
(
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(8,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (CompanyCode, ItemCode)
);


-- 協力会社職種リンクマスタ
CREATE TABLE SubContractorJobLink
(
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 職種キー
	JobCategoryCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(8,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (CompanyCode, JobCategoryCode)
);


-- 協力会社マスタ
CREATE TABLE SubContractorMaster
(
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 法人格名称
	CorporateStatusName nvarchar2(40) DEFAULT '',
	-- 法人格名称位置
	CorporateStatusPoint number(1) NOT NULL,
	-- 協力会社名
	CompanyName nvarchar2(100) DEFAULT '' NOT NULL,
	-- 代表者役職名
	CEOPositionName nvarchar2(60) DEFAULT '',
	-- 代表者氏名
	CEOName nvarchar2(60) DEFAULT '',
	-- 担当者氏名
	ContactPersonName nvarchar2(60),
	-- 郵便番号
	ZipCode varchar2(8),
	-- 住所１
	Address1 nvarchar2(60),
	-- 住所2
	Address2 nvarchar2(60) DEFAULT '',
	-- 住所3
	Address3 nvarchar2(60),
	-- 携帯電話番号
	CellPhoneNumber varchar2(13),
	-- メールアドレス
	MailAddress varchar2(257),
	-- 電話番号
	PhoneNumber varchar2(13) DEFAULT '',
	-- FAX番号
	FaxNumber varchar2(13) DEFAULT '',
	-- 50音読み
	JapaneseSyllabary nvarchar2(2),
	-- 取引開始年月日
	StartDate date NOT NULL,
	-- 備考
	Note nvarchar2(300) DEFAULT '',
	-- 支払い通常・手間区分
	labourKind number(1) NOT NULL,
	-- 削除フラグ
	DeleteFlg number(1) DEFAULT 0 NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (CompanyCode)
);


-- 仕入先マスタ
CREATE TABLE SuppliersMaster
(
	-- 仕入先コード
	SuppliersCode number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 仕入先名1
	SuppliersName1 nvarchar2(60) DEFAULT '' NOT NULL,
	-- 仕入先名２
	SuppliersName2 nvarchar2(60),
	-- 郵便番号
	ZipCode varchar2(8),
	-- 住所１
	Address1 nvarchar2(60),
	-- 住所2
	Address2 nvarchar2(60) DEFAULT '',
	-- 住所3
	Address3 nvarchar2(60),
	-- 電話番号
	PhoneNumber varchar2(13) DEFAULT '',
	-- FAX番号
	FaxNumber varchar2(13) DEFAULT '',
	-- 備考
	Note nvarchar2(300) DEFAULT '',
	-- 削除フラグ
	DeleteFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (SuppliersCode)
);


-- 管理マスタ
CREATE TABLE SystemMaster
(
	-- 会社コード
	SystemCode number(3,0) NOT NULL,
	-- 会社名１
	CompanyName1 nvarchar2(60) DEFAULT '' NOT NULL,
	-- 会社名２
	CompanyName2 nvarchar2(60) DEFAULT '',
	-- 代表者氏名
	CEOName nvarchar2(60) DEFAULT '' NOT NULL,
	-- 代表者役職名
	CEOPositionName nvarchar2(60) DEFAULT '',
	-- 郵便番号
	ZipCode varchar2(8) NOT NULL,
	-- 住所１
	Address1 nvarchar2(60) NOT NULL,
	-- 住所2
	Address2 nvarchar2(60) DEFAULT '',
	-- 住所3
	Address3 nvarchar2(60),
	-- 電話番号
	PhoneNumber varchar2(13) DEFAULT '' NOT NULL,
	-- FAX番号
	FaxNumber varchar2(13) DEFAULT '',
	-- 工事部経費
	ConstructionExpenses number(4,2) NOT NULL,
	-- 事務所経費
	OfficeExpenses number(4,2) NOT NULL,
	-- 営業経費
	OperatingExpenses number(4,2) NOT NULL,
	-- 消費税
	ConsumptionTax number(4,2) NOT NULL,
	-- Excel保存パス
	ExcelSavePath nvarchar2(120),
	-- 現在営業期数
	BusinessPeriod number(4,0) NOT NULL,
	-- 現在工事年度
	ConstructionYear number(4,0) NOT NULL,
	-- 営業期期首日
	BusinessBeginningDate varchar2(5) NOT NULL,
	-- 工事年度期首日
	ConstructionBeginningDate varchar2(5) NOT NULL,
	-- 工事番号基準値
	ConstructionNoBase number(1) NOT NULL,
	-- 標語1
	SloganString1 nvarchar2(100),
	-- 標語2
	SloganString2 nvarchar2(100),
	-- 標語3
	SloganString3 nvarchar2(100),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (SystemCode)
);


-- 期限マスタ
CREATE TABLE TermMaster
(
	-- 工事状態フラグ
	ConstructionStatusFlg number(2,0) NOT NULL,
	-- チェック対象フィールド番号
	FieldNo number(2,0) NOT NULL,
	-- 枝番
	SeqNo number(2,0) NOT NULL,
	-- 表示順
	DisplayOrder number(2,0) NOT NULL,
	-- チェックタイミング
	CheckSchdule number(1) NOT NULL,
	-- 経過日
	TermDays number(2,0) NOT NULL,
	-- タイトル
	SendTitile nvarchar2(100),
	-- メッセージ
	SendMessage nvarchar2(100),
	-- 背景色
	BackColor varchar2(8),
	-- 文字色
	ForeColor varchar2(8),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionStatusFlg, FieldNo, SeqNo)
);


-- 単位マスタ
CREATE TABLE UnitMaster
(
	-- 単位キー
	UnitKey number(5,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- 単位名称
	UnitName nvarchar2(30) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (UnitKey)
);


-- 車両マスタ
CREATE TABLE VehicleMaster
(
	-- 車両コード
	VehicleCode number(5,0) NOT NULL,
	-- 表示順
	displayOrder number(5,0) NOT NULL,
	-- 車両名称
	VehicleName nvarchar2(100) NOT NULL,
	-- 登録番号
	RegistrationNumber nvarchar2(30),
	-- 車体番号
	IdentificationNumber nvarchar2(30),
	-- 型式
	ModelCode nvarchar2(30),
	-- 管理部署
	DepartmentCode number(5,0) NOT NULL,
	-- 車両予約表示フラグ
	VehicleScheduleFlg number(1) NOT NULL,
	-- 購入日
	PurchaseDate date,
	-- 購入先
	PurchaseName nvarchar2(30),
	-- 購入先担当者
	PurchaseContactPersons nvarchar2(30),
	-- 購入先電話番号
	PurchasePhone varchar2(13),
	-- リース開始日
	LeaseDate date,
	-- リース先
	LeaseDestination nvarchar2(30),
	-- リース先担当者
	LeaseContactPersons nvarchar2(30),
	-- リース先電話番号
	LeasePhone varchar2(13),
	-- 任意保険会社
	InsuranceCompany nvarchar2(30),
	-- 任意保険会社担当者
	InsuranceContactPersons nvarchar2(30),
	-- 任意保険会社電話番号
	InsurancePhone nvarchar2(13),
	-- 備考
	Note nvarchar2(300),
	-- 登録日付
	EntryDate date,
	-- 更新日付
	UpdateDate date,
	PRIMARY KEY (VehicleCode)
);


-- 車両記録データ
CREATE TABLE VehicleRecordData
(
	-- 車両コード
	VehicleCode number(5,0) NOT NULL,
	-- データ区分
	DivisionCode number(2,0) NOT NULL,
	-- 枝番
	SeqNo number(3,0) NOT NULL,
	-- 実地日
	RecordDate date,
	-- 走行距離
	Mileage number(7,0),
	-- 内容
	Content nvarchar2(100),
	-- 費用
	PaymentCost number(10,2),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (VehicleCode, DivisionCode, SeqNo)
);



/* Create Indexes */

CREATE INDEX BusinessTypeMaster_Index1 ON BusinessTypeMaster (DisplayOrder);
CREATE INDEX ComponentLinkMaster_Index1 ON ComponentLinkMaster (ComponentCode);
CREATE INDEX ComponentLinkMaster_Index2 ON ComponentLinkMaster (ItemCode);
CREATE INDEX ComponentMaster_Index1 ON ComponentMaster (DisplayOrder);
CREATE INDEX ComponentToTypeMaster_Index1 ON ComponentToTypeMaster (ComponentCode);
CREATE INDEX ComponentToTypeMaster_Index2 ON ComponentToTypeMaster (TypeCode);
CREATE INDEX ConstructionSpecMaster_Index1 ON ConstructionSpecMaster (DisplayOrder);
CREATE INDEX DepartmentMaster_index1 ON DepartmentMaster (DisplayOrder);
CREATE INDEX HolidayCalender_Index1 ON HolidayCalenderMaster (BusinessYear);
CREATE INDEX HolidayCalenderMaster_Index2 ON HolidayCalenderMaster (TargetMonth);
CREATE INDEX HolidayCalenderMaster_Index3 ON HolidayCalenderMaster (TargetDay);
CREATE INDEX PersonInChargeMaster_Index1 ON PersonInChargeMaster (StartDate);
CREATE INDEX PersonInChargeMaster_Index2 ON PersonInChargeMaster (DepartmentCode);
CREATE INDEX SubContractorJobItem_Index1 ON SubContractorJobItem (CompanyCode);
CREATE INDEX SubContractorJobItem_Index2 ON SubContractorJobItem (ItemCode);
CREATE INDEX SubContractorJobLink_Index1 ON SubContractorJobLink (CompanyCode);
CREATE INDEX SubContractorJobLink_Index2 ON SubContractorJobLink (JobCategoryCode);
CREATE INDEX SubContractorMaster_Index1 ON SubContractorMaster (JapaneseSyllabary);
CREATE INDEX TermMaster_Index1 ON TermMaster (DisplayOrder);
CREATE INDEX UnitMaster_Index1 ON UnitMaster (DisplayOrder);



